# ‐*‐coding:utf‐8 ‐*‐ #
# ‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐
# ProjectName: program01
# FileName: db.py
# Author: Conner-Lee
# Datetime: 2024/11/9 09:58
# Description: 
# ‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐
import pymysql

from ApiAutoTest import logor, log
from ApiAutoTest.common.read_basic_ini import ReadBasicIni


class DB:

    def __init__(self):
        ini = ReadBasicIni()
        try:
            self.conn = pymysql.connect(
                host=ini.get_sql_connect("host"),
                port=int(ini.get_sql_connect("port")),
                user=ini.get_sql_connect("username"),
                password=ini.get_sql_connect("password"),
                database=ini.get_sql_connect("database"),
                autocommit=True,
                charset="utf8"
            )
            self.cursor = self.conn.cursor()
        except Exception as e:
            logor.error(f"链接数据库时出错，请求检查ini配置文件，发生的错误类型为：{type(e)}, 错误的描述为：{e}")
            raise e
    @log
    def delete(self, sql_sentence):
        """执行删除的sql语句"""
        if isinstance(sql_sentence, str) and sql_sentence.strip().lower().startswith("delete"):
            try:
                self.cursor.execute(sql_sentence)
            except Exception as e:
                # logor.error(f"执行的方法为：delete，功能描述为：执行删除的sql语句，传入的参数为：{sql_sentence}, 错误类型为：{type(e)}, 错误的描述为：{e}")
                raise ValueError(f"执行的方法为：delete，功能描述为：执行删除的sql语句，传入的参数为：{sql_sentence}, 错误类型为：{type(e)}, 错误的描述为：{e}")
        else:
            raise ValueError("SQL语句错误")

    @log
    def select(self, sql_sentence):
        if isinstance(sql_sentence, str) and sql_sentence.strip().lower().startswith("select"):
            try:
                self.cursor.execute(sql_sentence)
                select_result = self.cursor.fetchall()
                if select_result:
                    return select_result[0][0]
            except Exception as e:
                raise e
        else:
            logor.error(f"执行的方法为：select，功能描述为：执行查询的sql语句，传入的参数为：{sql_sentence}, 错误类型为：ValueError, 错误的描述为：sql语句错误")
            raise ValueError("sql语句错误")