# ‐*‐coding:utf‐8 ‐*‐ #
# ‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐
# ProjectName: program01
# FileName: read_excel.py
# Author: Conner-Lee
# Datetime: 2024/11/9 10:14
# Description: 
# ‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐‐
import openpyxl

from ApiAutoTest import log
from ApiAutoTest.common.read_basic_ini import ReadBasicIni
from ApiAutoTest.common.read_json import read_json
from ApiAutoTest.common.read_user_ini import ReadUserIni
from ApiAutoTest.data_config.settings import *


class ReadExcel:

    @log
    def __init__(self, user):
        """读取所有配置文件的数据"""
        # 创建ini对象
        ini = ReadUserIni(user)

        # 获取用户的json数据文件路径
        case_data_path = ini.get_file_path("case")
        expect_data_path = ini.get_file_path("expect")
        sql_data_path = ini.get_file_path("sql")

        self.case_data_dict = read_json(case_data_path)
        self.expect_data_dict = read_json(expect_data_path)
        self.sql_data_dict = read_json(sql_data_path)

        # 获取excel的路径
        excel_path = ini.get_file_path("excel")
        table_name = ini.get_table_name("name")

        try:
            workbook = openpyxl.load_workbook(excel_path)
            self.sheet = workbook[table_name]
        except Exception as e:
            raise e

    def __get_cell_value(self, colum: str, row: int) -> str:
        """获取指定单元格数据"""
        try:
            cell_value = self.sheet[colum + str(row)].value
            if cell_value is None:
                return None
            elif cell_value.strip():
                return cell_value.strip()
        except Exception as e:
            raise e

    @log
    def case_id(self, row):
        """获取用例的ID"""
        return self.__get_cell_value(CASEID, row)

    @log
    def module_name(self, row):
        """获取模块名称"""
        return self.__get_cell_value(MODULE, row)

    @log
    def api_name(self, row):
        """获取解耦名称"""
        return self.__get_cell_value(API, row)

    @log
    def title(self, row):
        """获取用例标题"""
        return self.__get_cell_value(TITLE, row)

    @log
    def level(self, row):
        """获取用例等级"""
        return self.__get_cell_value(LEVEL, row)

    @log
    def req_method(self, row):
        """获取请求方式"""
        return self.__get_cell_value(METHOD, row)

    @log
    def req_url(self, row):
        """获取请求的URL"""
        path = self.__get_cell_value(PATH, row)
        if path:
            return ReadBasicIni().get_host(HOST_NAME) + path

    @log
    def req_mime(self, row):
        """获取请求的媒体类型"""
        mime = self.__get_cell_value(MIME, row)
        if mime:
            return mime.lower()

    @log
    def case_data(self, row):
        """获取用例数据"""
        case_data_key = self.__get_cell_value(CASE, row)
        module_name = self.module_name(row)
        api_name = self.api_name(row)
        if case_data_key and module_name and api_name:
            return self.case_data_dict[module_name][api_name][case_data_key]

    @log
    def expect_data(self, row):
        """获取期望数据"""
        expect_data_key = self.__get_cell_value(EXPECT, row)
        module_name = self.module_name(row)
        api_name = self.api_name(row)
        if expect_data_key and module_name and api_name:
            return self.expect_data_dict[module_name][api_name][expect_data_key]

    @log
    def sql_type(self, row):
        """获取sql语句类型"""
        value = self.__get_cell_value(SQLTYPE, row)
        if value:
            return value.lower()

    @log
    def sql_data(self, row):
        sql_data_key = self.__get_cell_value(SQL, row)
        module_name = self.module_name(row)
        api_name = self.api_name(row)
        if sql_data_key and module_name and api_name:
            return self.sql_data_dict[module_name][api_name][sql_data_key]

    @log
    def update_keys(self, row):
        """获取用例标题"""
        return self.__get_cell_value(UPDATEKEY, row)

    @log
    def get_data(self):
        data_list = []
        for row in range(2,self.sheet.max_row+1):
            case_id = self.case_id(row)
            module = self.module_name(row)
            api = self.api_name(row)
            title = self.title(row)
            level = self.level(row)
            method = self.req_method(row)
            url = self.req_url(row)
            mime = self.req_mime(row)
            case_data = self.case_data(row)
            expect_data = self.expect_data(row)
            sql_type = self.sql_type(row)
            sql_data = self.sql_data(row)
            update_key = self.update_keys(row)
            if method and url and expect_data:
                data_list.append([case_id, module, api, title, level, method, url, mime, case_data, expect_data, sql_type, sql_data, update_key])
        else:
            return data_list
if __name__ == "__main__":
    excel = ReadExcel("zs_data")
    for data in excel.get_data():
        print(data)
    # print(excel.req_mime(3))
